chemcoord.Cartesian
===================

.. currentmodule:: chemcoord

.. autoclass:: Cartesian

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Cartesian.__init__
      ~Cartesian.add_data
      ~Cartesian.align
      ~Cartesian.apply
      ~Cartesian.applymap
      ~Cartesian.basistransform
      ~Cartesian.change_numbering
      ~Cartesian.check_absolute_refs
      ~Cartesian.check_dihedral
      ~Cartesian.copy
      ~Cartesian.correct_absolute_refs
      ~Cartesian.correct_dihedral
      ~Cartesian.cut_cuboid
      ~Cartesian.cut_sphere
      ~Cartesian.fragmentate
      ~Cartesian.from_ase_atoms
      ~Cartesian.from_pymatgen_molecule
      ~Cartesian.get_align_transf
      ~Cartesian.get_angle_degrees
      ~Cartesian.get_ase_atoms
      ~Cartesian.get_asymmetric_unit
      ~Cartesian.get_barycenter
      ~Cartesian.get_bond_lengths
      ~Cartesian.get_bonds
      ~Cartesian.get_centroid
      ~Cartesian.get_construction_table
      ~Cartesian.get_coordination_sphere
      ~Cartesian.get_dihedral_degrees
      ~Cartesian.get_distance_to
      ~Cartesian.get_electron_number
      ~Cartesian.get_equivalent_atoms
      ~Cartesian.get_fragment
      ~Cartesian.get_grad_zmat
      ~Cartesian.get_inertia
      ~Cartesian.get_pointgroup
      ~Cartesian.get_pymatgen_molecule
      ~Cartesian.get_shortest_distance
      ~Cartesian.get_total_mass
      ~Cartesian.get_without
      ~Cartesian.get_zmat
      ~Cartesian.has_same_sumformula
      ~Cartesian.insert
      ~Cartesian.partition_chem_env
      ~Cartesian.read_cjson
      ~Cartesian.read_xyz
      ~Cartesian.reindex_similar
      ~Cartesian.replace
      ~Cartesian.reset_index
      ~Cartesian.restrict_bond_dict
      ~Cartesian.set_index
      ~Cartesian.sort_index
      ~Cartesian.sort_values
      ~Cartesian.subs
      ~Cartesian.symmetrize
      ~Cartesian.to_cjson
      ~Cartesian.to_latex
      ~Cartesian.to_string
      ~Cartesian.to_xyz
      ~Cartesian.to_zmat
      ~Cartesian.view
      ~Cartesian.write_xyz
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Cartesian.columns
      ~Cartesian.dtypes
      ~Cartesian.empty
      ~Cartesian.iloc
      ~Cartesian.index
      ~Cartesian.loc
      ~Cartesian.shape
   
   